/*
 * @production.java Version 1.1 06/11/2012
 *
 * Copyright (c) 2012 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

import java.net.*;
import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import javax.swing.*;

import cmn.cmnStruct;
import production.productionListStruct;       // Production List Structure
import production.productionStruct;           // Production Data Structure
import production.io.ReadProductionXMLFile;   // Read Production XML File
import production.gui.productionPlotFrame;    // Production Frame

/** Class production
 *  <p> This Class is the starting point for the Digitizer Web App.
 *
 *  @version 1.1 06/11/2012
 *  @author  John R. Victorine
 */

public class production extends Applet
{
  public static final int NONE     = -1;
  public static final int FLUID    = 0; //production.productionStruct.FLUID;
  public static final int INJ      = 1;

  // Runtime object

  private Runtime r = Runtime.getRuntime();

  // Web Application is runing Stand Alone Indicator

  private boolean isStandalone = false;

  private String  sKID             = new String("0"); // Production KID
  private String  sKID_Standalone  = new String("0");

  private String  sType            = new String("0"); // Type of Production
  private String  sType_Standalone = new String("0");

  // LAS Viewer Global Variables

//  private iqstratStruct stStruct = new iqstratStruct();
  private cmnStruct     stCMN    = new cmnStruct();
  private String        sPath    = new String(".");
  private int           iByType  = NONE;

//  private productionListStruct stList = null; // Production List Structure

  /** getParameter()
   *  <p> This method wil get a parameter value
   *  @param key = The Name of the Parameter
   *  @param def = The Object Type of the Parameter
   *  @return Parameter
   */

  public String getParameter(String key, String def)
  {
    return (isStandalone ? System.getProperty(key, def) :
            (getParameter(key) != null ? getParameter(key) : def));
  }

  /** Constructor production()
   *  <p> This is the Constructor for this class.
   */

  public production() {  }

  /** Method init()
   *  <p> This Method will retrieve the data values from the HTML or the main()
   *      arguments and run the Stratigraphic Data Collection and Biostratigraphy Profile
   *      Viewer Module.
   */

  public void init()
  {
    try
    {
      sKID = this.getParameter("sKID", sKID_Standalone);
      if (sKID.equals("undefined"))
        sKID = new String("0");
    }
    catch(Exception e)
    {
      e.printStackTrace();
    }

    try
    {
      sType = this.getParameter("sType", sType_Standalone);
      if (sType.equals("undefined"))
        sType = new String("");

      if (sType.length() > 0)
      {
		if (sType.equals("FLUID"))
		  iByType = FLUID;
		else if (sType.equals("INJECTION"))
		  iByType = INJ;
	  }
    }
    catch(Exception e)
    {
      e.printStackTrace();
    }

//System.out.println(iByType+" "+sType+"="+sKID);
    try
    {
      jbInit();
    }
    catch(Exception e)
    {
      e.printStackTrace();
    }
  }

  /** Method jbInit()
   *  <p> This method will launch the Field LAS Catalog.
   * @throws Exception
   */

  private void jbInit() throws Exception
  {
    productionPlotFrame  plot   = null; // Production Frame
    productionListStruct stList = null; // Production List Structure

    // initialize Global LAS Data Structure

    stCMN.bStandalone   = isStandalone;

    // Retrieve KGS Image Icon for printing

    if (!isStandalone)
    {
      stCMN.urlDirCodeBase = getCodeBase();
      stCMN.appletContext  = getAppletContext();
      stCMN.pIcon          = getImage(getCodeBase(), cmn.cmnStruct.ICON);
      stCMN.pIcon2         = getImage(getCodeBase(), cmn.cmnStruct.ICON2);
    }
    else
    {
      URL url = null;

      stCMN.urlDirCodeBase =  getClass().getClassLoader().getResource(".");

      ClassLoader cl = this.getClass().getClassLoader();
      sPath = cl.getResource("images").toString();
      stCMN.sImagePath = new String(sPath);

      try
      {
        url = new URL(sPath+"\\kgsSm.png");
        stCMN.pIcon = Toolkit.getDefaultToolkit().getImage(url);
        url = new URL(sPath+"\\kgsSm2.png");
        stCMN.pIcon2 = Toolkit.getDefaultToolkit().getImage(url);
      }
      catch (java.net.MalformedURLException e)
      {
        e.printStackTrace();
        String sMessage = new String("production(): \n" +
                              e.getMessage() + "\n" +
                              "Couldn't create image: " + sPath+"\\kgsSm.gif");
        JOptionPane.showMessageDialog((Component) null,
                                      sMessage,
                                      "ERROR",
                                      JOptionPane.ERROR_MESSAGE);
      }
    }

    // Get the Path of the XML Files stored in JAR File.

    ClassLoader cl   = this.getClass().getClassLoader();
//    sPath            = cl.getResource("data").toString();
//    stCMN.sPath      = new String(sPath);

    sPath            = cl.getResource("images").toString();
    stCMN.sImagePath = new String(sPath);
    stCMN.cl         = cl;

//    stStruct.stCMN   = stCMN;

    // Display the Production Plot

    stList = getData();

	if (stList != null)
	{
	  plot = new productionPlotFrame( stList );
	}
  }

  /* ===================================================================== *
   * -------------------------- GET METHODS ------------------------------ *
   * ===================================================================== */

  /** Method getData()
   * <p> This method will retrieve the KGS Production Data.
   */

  private productionListStruct getData()
  {
    ReadProductionXMLFile pData  = null;
    String                sQuery = "";
    productionListStruct  stList = null; // Production List Structure

    pData  = new ReadProductionXMLFile(1);

    switch (iByType)
    {
      case FLUID:
        sQuery = new String("sFluid=" + sKID);
        stList = pData.Process(cmn.cmnStruct.KGS_PRODUCTION+sQuery);
        break;
      case INJ:
        sQuery = new String("sINJ=" + sKID);
        stList = pData.Process(cmn.cmnStruct.KGS_INJECTION+sQuery);
        break;
	}


    return (stList);
  }

  /* ======================================================================= *
   * --------------------------- APPLET METHODS ---------------------------- *
   * ======================================================================= */

  /** Method start()
   *  <p> This method will start the applet
   */

  public void start() { }

  /** Method stop()
   *  <p> This method will stop the applet
   */

  public void stop() { }

  /** Method destroy()
   *  <p> This method will destroy the applet
   */

  public void destroy() { }

  /** Method getAppletInfo()
   *  <p> This method will return Applet information
   *  @return - Info
   */

  public String getAppletInfo() { return ("Digitize E-Logs"); }

  /** Method getParameterInfo()
   *  <p> This method will get the parameter info
   *  @return pinfo - Array of Parameters Expected.
   */

  public String[][] getParameterInfo()
  {
    String[][] pinfo = { {"sKID",  "String", "Production Primary Key"},
                         {"sType", "String", "Production Type"}};

    return pinfo;
  }

  /** Method main()
   *  <p> This method will allow this Module to run either as an Application or
   *      an Applet.
   *  @param args = The Arguments passed in to query for the production data
   */

  public static void main(String[] args)
  {
    production applet = new production();

    applet.isStandalone     = true;
    applet.sKID_Standalone  = new String("0");
    applet.sType_Standalone = new String("");

    if (args.length > 0)
    {
      applet.sType_Standalone = new String(args[0]);
      applet.sKID_Standalone  = new String(args[1]);
	}

    applet.init();
    applet.start();
  }
}


/*
 *  @version 1.1 06/11/2012
 *  @author  John Victorine
 */
