/*
 * @productionIO_Files.java Version 1.0 09/19/2013
 *
 * Copyright (c) 2013 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package production.io;

import java.io.*;
import java.awt.*;
import java.awt.image.*;
import javax.swing.*;

import util.utilFileIO;
import util.utilImageIO;

/** Class productionIO_Files
 *  <p> This class will manage the plot output for the profile plot
 *
 *  @version 1.1 09/19/2013
 *  @author  John R. Victorine
 */

public class productionIO_Files
{
  /** Method getHomeDir()
   * <p> This method will retrieve the User's Home Directory
   * @return sDirectory = The User Home Directory
   */

  public static String getHomeDir()
  {
    String sDir = "";    // User Home Directory
    File   pDir = null;  // User Home Directory File Object

    try
    {
      pDir = new File( System.getProperty( "user.home" ) );
      sDir = new String( pDir.getCanonicalPath() );
    }
    catch (Exception e)
    {
      e.printStackTrace();
      String sError = new String("productionIO_Files.getHomeDir()\n "+e.toString());
      JOptionPane.showMessageDialog(
        (Component) null, sError, "ERROR", JOptionPane.ERROR_MESSAGE);
    }

    return (sDir);
  }

  /** Method createImage()
   * <p> this method will create an image from the Plot image
   *  @param sPath = Directory Path for the Image file
   *  @param sName = Filename of the Image file
   *  @param image = Profile Plot Buffered Image
   */

  public static void createImage( String sPath, String sName, BufferedImage image )
  {
    String sOut  = "";

    sOut = sPath  + "/" + sName + ".png";

    utilImageIO pImage = new utilImageIO( image );
    pImage.save( sOut );

    image = null;
    sOut  = null;
  }

  /** Method createHTML()
   * <p> this method will create an html file from the Plot image
   *  @param sPath = Directory Path for the Image file
   *  @param sName = Filename of the Image file
   */

  public static void createHTML( String sPath, String sName )
  {
    int           iError = util.utilFileIO.NOERROR;
    String        sOut   = sName + ".html";
    String        sHTML  = "";
    utilFileIO    pIO    = null;

    // Create HTML Document

    sHTML = new String(sHTML + "<html>\n");
    sHTML = new String(sHTML + "  <head>\n");
    sHTML = new String(sHTML + "    <title>Production Plot</title>\n");
    sHTML = new String(sHTML + "  </head>\n");

    sHTML = new String(sHTML + "  <body>\n");
    sHTML = new String(sHTML + "    <a href=\"http://www.kgs.ku.edu/PRS/Ozark/TYPE_LOG/PDF.html\"> " +
                               "Create a PDF Document of this PNG Image</a>\n");
    sHTML = new String(sHTML + "    <p>\n");
    sHTML = new String(sHTML + "    <img src=\"" + sName + ".png\">\n");
    sHTML = new String(sHTML + "  </body>\n");
    sHTML = new String(sHTML + "</html>\n");

    // Write HTML Document to Temporary File

    pIO  = new utilFileIO();
    pIO.Open(util.utilFileIO.DIRECTORY, util.utilFileIO.WRITE, sPath, sOut);
    pIO.Write(sHTML);

    if (iError == util.utilFileIO.NOERROR)
      pIO.Close();

    pIO.delete();
    pIO = null;

    util.BrowserControl.displayURL(sPath + "\\" + sOut);

    sOut  = null;
    sPath = null;
    sHTML = null;
  }

  /** Method createHTML()
   * <p> this method will create an html file from the Plot image
   *  @param sPath = Directory Path for the Image file
   *  @param sName = Filename of the Image file
   */

  public static void createHTMLSimple( String sPath, String sName )
  {
    int           iError = util.utilFileIO.NOERROR;
    String        sOut   = sName + ".html";
    String        sHTML  = "";
    utilFileIO    pIO    = null;

    // Create HTML Document

    sHTML = new String(sHTML + "<html>\n");
    sHTML = new String(sHTML + "  <head>\n");
    sHTML = new String(sHTML + "    <title>Production Plot</title>\n");
    sHTML = new String(sHTML + "  </head>\n");

    sHTML = new String(sHTML + "  <body>\n");
    sHTML = new String(sHTML + "    <img src=\"" + sName + ".png\">\n");
    sHTML = new String(sHTML + "  </body>\n");
    sHTML = new String(sHTML + "</html>\n");

    // Write HTML Document to Temporary File

    pIO  = new utilFileIO();
    pIO.Open(util.utilFileIO.DIRECTORY, util.utilFileIO.WRITE, sPath, sOut);
    pIO.Write(sHTML);

    if (iError == util.utilFileIO.NOERROR)
      pIO.Close();

    pIO.delete();
    pIO = null;

    util.BrowserControl.displayURL(sPath + "\\" + sOut);

    sOut  = null;
    sPath = null;
    sHTML = null;
  }
}

/*
 *  @version 1.1 09/19/2013
 *  @author  John Victorine
 */
