/*
 * @productionPlotStruct.java Version 1.1 03/30/2016
 *
 * Copyright (c) 2016 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package production;

import java.sql.Timestamp;

/** Class productionPlotStruct
 *  <p> This Class holds the information that was parsed from the miniSeed
 *      file using the IRIS (Incorporated Research Institutions
 *      for Seismology) source code.
 *
 *  @version 1.1 03/30/2016
 *  @author  John R. Victorine
 */

public class productionPlotStruct
{
  public static final int FLUID    = 0;
  public static final int INJ      = 1;

  public static final int    iDATA_BY  = 2;
  public static final String DATA_BY[] = { "FLUID", "INJECTION" };

//  public static final int    OIL       = 0;
//  public static final int    GAS       = 1;

//  public static final String PRODUCT[] = { "OIL", "GAS" };
//  public static final String UNITS[]   = { "BBL", "MCF" };

  // Identifying information for the Production Data

  public String    sKID      = "0";   // KID for the Production Data
  public String    sID       = "0";   // Other ID for the Production Data
  public String    sProduct  = "";    // Type of Production Data
  public String    sName     = "";    // Name of Production Data
  public String    sAPI      = "";    // API-Number

  public String    sApp      = "";    // URL retrieving Data
  public String    sBy       = "";    // Search By

  public String    sUnits    = "";    // Units

  // Plot Limits

  public Timestamp tsStart   = null; // Starting Timestamp
  public Timestamp tsEnd     = null; // Ending Timestamp

  public double    dMaximum  = 0.0;  // Maximum Data Value
  public double    dMinimum  = 0.0;  // Minimum Data Value

  // Plot Dimensions

  public int       iWidth    = 1200; // Actual Plotting Width
  public int       iHeight   =  800; // Actual plotting Height

  // Seismic Records

  public int       iRows     = 0;    // Total Number of rows
  public Timestamp ts[]      = null; // Time Stamp of data records
  public double    dRaw[]    = null; // Raw Data records
  public double    dAvg[]    = null; // Average Raw Data records
  public double    dMedian[] = null; // Median Raw Data
  public double    dCUM[]    = null; // Cumulative Data records
  public String    sType[]   = null; // Type of Data

  /** Method delete()
   *  <p> This method deallocates the data to force Java to release memory
   *      allocated for the data
   */

  public void delete()
  {
    sKID     = null;   // KID for the Production Data
    sID      = null;   // Other ID for the Production Data
    sProduct = null;    // Type of Production Data
    sName    = null;    // Name of Production Data
    sAPI     = null;    // API-Number

    // Plot Limits

    tsStart  = null; // Starting Timestamp
    tsEnd    = null; // Ending Timestamp

    // Seismic Records

    iRows    = 0;    // Total Number of rows
    ts       = null; // Time Stamp of data record
    dRaw     = null; // Raw Data records
    dAvg     = null; // Average Data records
    dMedian  = null; // Median
    dCUM     = null; // Cumulative Data
    sType    = null; // Type of Data, i.e. OIL, GAS, CO2, etc.
  }
}

/*
 *  @version 1.1 03/30/2016
 *  @author  John Victorine
 */
